@@ -94,7 +94,7 @@ def _add_and_update_pics(pic_file_gen, session) -> bool:
                 log.debug(f"Checked {count} files for necessary db updates.")
         except Exception as e:
             log.error(
-                f"Exception while trying to update db with {pic_file}.", exc_info=e
+                f"Exception while trying to update db with {pic_file.path}.", exc_info=e
             )
             session.rollback()
     return num_changed > 0
