@@ -248,7 +248,7 @@ def convert_to_absolute_path(rel_path):
         return os.path.abspath(rel_path)
     else:
         new_path = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)), "..", rel_path
+            os.path.dirname(os.path.abspath(__file__)), "../..", rel_path
         )
         if os.path.isfile(new_path):
             return new_path
