@@ -102,9 +102,9 @@ class NextPictureManager:
         if self.last_db_update < last_db_update:
             q = session.query(PictureData)
             if FILTER_RATING_BELOW in self.filters:
-                q = q.filter(PictureData.rating <= self.filters[FILTER_RATING_BELOW])
+                q = q.filter(PictureData.rating >= self.filters[FILTER_RATING_BELOW])
             if FILTER_RATING_ABOVE in self.filters:
-                q = q.filter(PictureData.rating >= self.filters[FILTER_RATING_ABOVE])
+                q = q.filter(PictureData.rating <= self.filters[FILTER_RATING_ABOVE])
             full_picture_list = q.all()
             log.info(f"{len(full_picture_list)} pictures loaded.")
             session.close()
